<?php

declare(strict_types=1);

namespace Drupal\Tests\date_point\Kernel;

use DateTimeImmutable as DTI;
use Drupal\date_point\StateClock;
use Drupal\KernelTests\KernelTestBase;
use Psr\Clock\ClockInterface;

/**
 * A test for state clock service.
 *
 * @group date_point
 */
final class StateClockTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['date_point'];

  /**
   * {@selfdoc}
   */
  public function testStateClock(): void {
    $clock = $this->container->get('date_point.state_clock');
    // -- Test implementation of ClockInterface
    \assert($clock instanceof ClockInterface);
    self::assertInstanceOf(DTI::class, $clock->now());
    self::assertContains(\time() - $clock->now()->getTimestamp(), [0, 1]);
    // -- Test state clock.
    \assert($clock instanceof StateClock);
    self::assertContains(\time() - $clock->get()->getTimestamp(), [0, 1]);
    $clock->set(new DTI('2024-06-15 15:00:00+00:00'));
    self::assertEquals($clock->now(), new DTI('2024-06-15 15:00:00+00:00'));
    $clock->set(new DTI('2021-10-15 15:24:05.123456+00:00'));
    self::assertEquals($clock->now(), new DTI('2021-10-15 15:24:05.123456+00:00'));
    self::assertEquals($clock->now()->modify('+10 days'), new DTI('2021-10-25 15:24:05.123456+00:00'));
    $clock->reset();
    self::assertContains(\time() - $clock->get()->getTimestamp(), [0, 1]);
  }

}
